@@ -1,7 +1,7 @@
 # coding: utf8
 # Part of the bioread package for reading BIOPAC data.
 #
-# Copyright (c) 2022 Board of Regents of the University of Wisconsin System
+# Copyright (c) 2023 Board of Regents of the University of Wisconsin System
 #
 # Written Nate Vack <njvack@wisc.edu> with research from John Ollinger
 # at the Waisman Laboratory for Brain Imaging and Behavior, University of
@@ -319,6 +319,7 @@ class Reader(object):
             marker_channel = self.datafile.channel_order_map.get(
                 mih.channel_number)
             event_markers.append(EventMarker(
+                time_index=(mih.sample_index * self.graph_header.sample_time) / 1000,
                 sample_index=mih.sample_index,
                 text=marker_text,
                 channel_number=mih.channel_number,
@@ -528,7 +529,7 @@ def chunk_pattern(byte_pattern, channel_bytes_remaining):
         for i, rem in enumerate(channel_bytes_remaining)
     ]
     all_byte_indexes = np.concatenate(channel_byte_indexes)
-    pattern_mask = np.zeros(len(byte_pattern), dtype=np.bool)
+    pattern_mask = np.zeros(len(byte_pattern), dtype=bool)
     pattern_mask[all_byte_indexes] = True
     return byte_pattern[pattern_mask]
 
